The arsenal is an assortment of python utilities that I can't live without.

### Documentation
[Read the Docs](https://python-arsenal.readthedocs.io/en/latest/)

### Installation
Below are two method to install this repo.

1) Clone and pip-install
```
$ git clone https://github.com/timvieira/arsenal.git
$ cd arsenal 
$ pip install .
```
Now, if you like, you can delete the directory `rm -rf ../arsenal`.

2) Use pip for the whole thing.
```
$ pip install -r https://raw.githubusercontent.com/timvieira/arsenal/master/requirements.txt
$ pip install git+https://github.com/timvieira/arsenal.git 
```
Unforuntately, just running the second command fails to identify the requirements file.
